@@ -1,26 +1,15 @@
-
-
 #' Data Class and Tools for Handling Spatial-Temporal Data
-#' 
-#' Data class for increased interoperability working with spatial-temporal 
-#' data together with corresponding functions and methods (conversions, 
+#'
+#' Data class for increased interoperability working with spatial-temporal
+#' data together with corresponding functions and methods (conversions,
 #' basic calculations and basic data manipulation). The class distinguishes
 #' between spatial, temporal and other dimensions to facilitate the development
 #' and interoperability of tools build for it. Additional features are name-based
-#' addressing of data and internal consistency checks (e.g. checking for the 
+#' addressing of data and internal consistency checks (e.g. checking for the
 #' right data order in calculations).
-#' 
+#'
 #' @name magclass-package
 #' @aliases magclass-package magclass
-#' @docType package
-#' @author 
-#' Maintainer: Jan Philipp Dietrich <dietrich@@pik-potsdam.de>
-NULL
-
-
-
-
-
-
-
-
+#' @author
+#' Maintainer: Jan Philipp Dietrich <dietrich@pik-potsdam.de>
+"_PACKAGE"
